Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 78213)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 78214)
@@ -416,5 +416,6 @@
 UIWizardImportAppPageBasic1::UIWizardImportAppPageBasic1(bool fImportFromOCIByDefault)
     : UIWizardImportAppPage1(fImportFromOCIByDefault)
-    , m_pLabel(0)
+    , m_pLabelMain(0)
+    , m_pLabelDescription(0)
 {
     /* Create main layout: */
@@ -422,10 +423,12 @@
     if (pMainLayout)
     {
-        /* Create label: */
-        m_pLabel = new QIRichTextLabel(this);
-        if (m_pLabel)
-        {
+        /* Create main label: */
+        m_pLabelMain = new QIRichTextLabel(this);
+        if (m_pLabelMain)
+        {
+            m_pLabelMain->hide();
+
             /* Add into layout: */
-            pMainLayout->addWidget(m_pLabel);
+            pMainLayout->addWidget(m_pLabelMain);
         }
 
@@ -446,5 +449,4 @@
                 m_pSourceLayout->addWidget(m_pSourceLabel, 0, 0, Qt::AlignRight);
             }
-
             /* Create source selector: */
             m_pSourceComboBox = new QIComboBox(this);
@@ -456,4 +458,12 @@
                 /* Add into layout: */
                 m_pSourceLayout->addWidget(m_pSourceComboBox, 0, 1);
+            }
+
+            /* Create description label: */
+            m_pLabelDescription = new QIRichTextLabel(this);
+            if (m_pLabelDescription)
+            {
+                /* Add into layout: */
+                m_pSourceLayout->addWidget(m_pLabelDescription, 1, 0, 1, 2);
             }
 
@@ -673,8 +683,8 @@
     setTitle(UIWizardImportApp::tr("Appliance to import"));
 
-    /* Translate label: */
-    m_pLabel->setText(UIWizardImportApp::tr("<p>VirtualBox currently supports importing appliances "
-                                            "saved in the Open Virtualization Format (OVF). "
-                                            "To continue, select the file to import below.</p>"));
+    /* Translate main label: */
+    m_pLabelMain->setText(UIWizardImportApp::tr("Please choose the source to import appliance from.  This can be a "
+                                                "local file system to import OVF archive or one of known  cloud "
+                                                "service providers to import cloud VM from."));
 
     /* Translate source label: */
@@ -804,4 +814,28 @@
 }
 
+void UIWizardImportAppPageBasic1::updatePageAppearance()
+{
+    /* Call to base-class: */
+    UIWizardImportAppPage1::updatePageAppearance();
+
+    /* Update page appearance according to chosen storage-type: */
+    if (isSourceCloudOne())
+    {
+        m_pLabelDescription->setText(UIWizardImportApp::
+                                     tr("<p>Please choose one of cloud service accounts you have registered to import virtual "
+                                        "machine from.  Corresponding machines list will be updated.  To continue, "
+                                        "select one of machines to import below.</p>"));
+        m_pAccountInstanceList->setFocus();
+    }
+    else
+    {
+        m_pLabelDescription->setText(UIWizardImportApp::
+                                     tr("<p>Please choose a file to import the virtual appliance from.  VirtualBox currently "
+                                        "supports importing appliances saved in the Open Virtualization Format (OVF).  "
+                                        "To continue, select the file to import below.</p>"));
+        m_pFileSelector->setFocus();
+    }
+}
+
 void UIWizardImportAppPageBasic1::sltHandleSourceChange()
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h	(revision 78213)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h	(revision 78214)
@@ -180,4 +180,7 @@
     virtual bool validatePage() /* override */;
 
+    /** Updates page appearance. */
+    virtual void updatePageAppearance() /* override */;
+
 private slots:
 
@@ -193,6 +196,8 @@
 private:
 
-    /** Holds the label instance. */
-    QIRichTextLabel *m_pLabel;
+    /** Holds the main label instance. */
+    QIRichTextLabel *m_pLabelMain;
+    /** Holds the description label instance. */
+    QIRichTextLabel *m_pLabelDescription;
 };
 
